@@ -1,11 +1,5 @@
 #!/bin/sh
 
-if test -z $1
-then
-    echo "Usage : $0 <version> (e.g. \"1.3\")"
-    exit 1
-fi
-
 function cmd_to_devnull() {
     $* > /dev/null 2>/dev/null
     if test $? -ne 0
@@ -15,9 +9,11 @@ function cmd_to_devnull() {
     fi
 }
 
-echo "[+] Adding GIT tag v$1"
-cmd_to_devnull git tag v$1
-cmd_to_devnull git push origin v$1
+KS_VERSION=$(grep "VERSION =" lib/Keystone.pm | awk -F\' '{print $2}')
+
+echo "[+] Adding GIT tag v$KS_VERSION"
+cmd_to_devnull git tag v$KS_VERSION
+cmd_to_devnull git push origin v$KS_VERSION
 
 
 echo ""
@@ -28,8 +24,8 @@ if test ! -d pkgs/cpan
 then
     mkdir pkgs/cpan
 fi
-cmd_to_devnull scripts/gen_cpan_zip.sh $1
-echo "[+] You can upload pkgs/cpan/Keystone-$1.zip to : https://pause.perl.org/pause/authenquery?ACTION=add_uri"
+cmd_to_devnull scripts/gen_cpan_zip.sh
+echo "[+] You can upload pkgs/cpan/Keystone-$KS_VERSION.zip to : https://pause.perl.org/pause/authenquery?ACTION=add_uri"
 
 echo ""
 echo ""
@@ -37,7 +33,7 @@ echo "~~~~~~~~~~ ArchLinux ~~~~~~~~~~~"
 echo "[+] Genere archlinux package"
 
 cd pkgs/archlinux
-sed -i -r "s/pkgver=.+/pkgver=$1/g" PKGBUILD
+sed -i -r "s/pkgver=.+/pkgver=$KS_VERSION/g" PKGBUILD
 
 SHA_SUMS=$(makepkg -g 2>/dev/null)
 sed -i -r "s/sha256sums=.+/$SHA_SUMS/g" PKGBUILD
@@ -45,10 +41,8 @@ sed -i -r "s/sha256sums=.+/$SHA_SUMS/g" PKGBUILD
 cmd_to_devnull mksrcinfo
 cmd_to_devnull chmod 0644 PKGBUILD .SRCINFO
 cmd_to_devnull git add PKGBUILD .SRCINFO
-git commit -m v$1 >/dev/null 2>/dev/null
+git commit -m v$KS_VERSION >/dev/null 2>/dev/null
 cmd_to_devnull git push
 cmd_to_devnull makepkg -f --source
 
-echo "[+] You can upload pkg/archlinux/*.src.tar.gz to : https://aur.archlinux.org/submit/"
-
-echo "[+] Keystone v$1 released !"
+echo "[+] Keystone v$KS_VERSION released !"
